@@ -150,7 +150,7 @@ class ATM(object):
     # use a sha1 hash to convert the url into a unique filepath
     hash_file = "%s.%s" % (sha1(url).hexdigest(), self.format)
     if interval_string:
-      hash_file = "%s-%s" % (interval_string, hash_file)
+      hash_file = "%s-%s" % (str(interval_string), hash_file)
 
     return os.path.join(self.cache_dir, hash_file)
 
@@ -164,7 +164,7 @@ class ATM(object):
 
   def _round_timestamp_to_interval(self, ts):
     """Generate a timestamp string that will be used to update the cache at a set interval"""
-    return int(ts) - int(ts % int(self.interval))
+    return str(int(ts) - int(ts % int(self.interval)))
 
 
 
